<?php
/**
 * Modern Magazine Theme Customizer
 *
 * @package Modern_Magazine
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if ( ! function_exists( 'modern_magazine_field_sanitize_checkbox' ) ) :
  function modern_magazine_field_sanitize_checkbox( $checked ) {
    return ( ( isset( $checked ) && true === $checked ) ? true : false );
}
endif;

if ( ! function_exists( 'modern_magazine_field_sanitize_input_choice' ) ) :
function modern_magazine_field_sanitize_input_choice( $input, $setting ) {

  // Ensure input is a slug.
  $input = sanitize_key( $input );

  // Get list of choices from the control associated with the setting.
  $choices = $setting->manager->get_control( $setting->id )->choices;

  // If the input is a valid key, return it; otherwise, return the default.
  return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}
endif;

if ( ! function_exists( 'modern_magazine_posts_category' ) ) :
function modern_magazine_posts_category(){
  $args = array('parent' => 0);
  $categories = get_categories($args);
  $category = array();
  $i = 0;
  foreach($categories as $categorys){
      if($i==0){
          $default = $categorys->slug;
          $i++;
      }
      $category[$categorys->slug] = $categorys->name;
  }
  return $category;
}
endif;

function modern_magazine_customize_register( $wp_customize ) {
	  $wp_customize->add_panel(
    'general',
    array(
        'title' => __( 'General', 'modern-magazine' ),
        'description' => __('styling options','modern-magazine'),
        'priority' => 20, 
    )
  );
   //All our sections, settings, and controls will be added here
  $wp_customize->add_section(
    'TopHeaderSocialLinks',
    array(
      'title' => __('Top Header Social Accounts', 'modern-magazine'),
      'priority' => 120,
      'description' => balanceTags( 'In first input box, you need to add FONT AWESOME shortcode which you can find <a target="_blank" href="https://fortawesome.github.io/Font-Awesome/icons/">here</a> and in second input box, you need to add your social media profile URL.<br /> Enter the URL of your social accounts. Leave it empty to hide the icon.' , true),
      'panel' => 'general'
    )
  );

$TopHeaderSocialIcon = array();
  for($i=1;$i <= 5;$i++):  
    $TopHeaderSocialIcon[] =  array( 'slug'=>sprintf('TopHeaderSocialIcon%d',$i),   
      'default' => '',   
      'label' => esc_html__( 'Social Account ', 'modern-magazine' ). $i,   
      'priority' => sprintf('%d',$i) );  
  endfor;
  foreach($TopHeaderSocialIcon as $TopHeaderSocialIcons){
    $wp_customize->add_setting(
      $TopHeaderSocialIcons['slug'],
      array(
        'default' => '',
        'capability'     => 'edit_theme_options',
        'type' => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
      )
    );
    $wp_customize->add_control(
      $TopHeaderSocialIcons['slug'],
      array(
        'type'  => 'text',
        'section' => 'TopHeaderSocialLinks',
        'input_attrs' => array( 'placeholder' => esc_attr__('Enter Icon','modern-magazine') ),
        'label'      =>   $TopHeaderSocialIcons['label'],
        'priority' => $TopHeaderSocialIcons['priority']
      )
    );
  }
  $TopHeaderSocialIconLink = array();
  for($i=1;$i <= 5;$i++):  
    $TopHeaderSocialIconLink[] =  array( 'slug'=>sprintf('TopHeaderSocialIconLink%d',$i),   
      'default' => '',   
      'label' => esc_html__( 'Social Link ', 'modern-magazine' ). $i,
      'priority' => sprintf('%d',$i) );  
  endfor;
  foreach($TopHeaderSocialIconLink as $TopHeaderSocialIconLinks){
    $wp_customize->add_setting(
      $TopHeaderSocialIconLinks['slug'],
      array(
        'default' => '',
        'capability'     => 'edit_theme_options',
        'type' => 'theme_mod',
        'sanitize_callback' => 'esc_url_raw',
      )
    );
    $wp_customize->add_control(
      $TopHeaderSocialIconLinks['slug'],
      array(
        'type'  => 'text',
        'section' => 'TopHeaderSocialLinks',
        'priority' => $TopHeaderSocialIconLinks['priority'],
        'input_attrs' => array( 'placeholder' => esc_html__('Enter URL','modern-magazine')),
      )
    );
  }

  $wp_customize->add_section(
    'ModernMagazineSocialLinks',
    array(
      'title' => __('Social Accounts', 'modern-magazine'),
      'priority' => 120,
      'description' => balanceTags( 'In first input box, you need to add FONT AWESOME shortcode which you can find <a target="_blank" href="https://fortawesome.github.io/Font-Awesome/icons/">here</a> and in second input box, you need to add your social media profile URL.<br /> Enter the URL of your social accounts. Leave it empty to hide the icon.' , true),
      'panel' => 'footer'
    )
  );
  $wp_customize->get_section('title_tagline')->panel = 'general';
  $wp_customize->get_section('header_image')->panel = 'general';
  $wp_customize->get_section('title_tagline')->title = __('Header & Logo','modern-magazine');


$wp_customize->add_section(
  'headerNlogo',
  array(
    'title' => __('Header & Logo','modern-magazine'),
    'panel' => 'general'
  )
);
/*Home page Template settings*/
$wp_customize->add_panel(
    'home_template_settings',
    array(
        'title' => __( 'Front Page Settings', 'modern-magazine' ),
        'description' => __('styling options','modern-magazine'),
        'priority' => 20, 
    )
  );

/*Front Page : Slider Area*/
$wp_customize->add_section(
  'front_page_home_template_settings',
  array(
    'title' => __('Front Page : Slider Area','modern-magazine'),
    'panel' => 'home_template_settings',
    'description' => __('Using this option you can display the category wise posts on slider area.','modern-magazine'),
  )
);
$wp_customize->add_setting(
  'post_category',
  array(
    'default' => 'uncategorized',
    'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'post_category',
  array(
    'label' => __('Select Category','modern-magazine'),
    'section' => 'front_page_home_template_settings',
    'type'    => 'select',
    'choices' => modern_magazine_posts_category(),
  )
);
/*Front Page : Area Below Slider*/
$wp_customize->add_section(
  'front_page_area_below_slider',
  array(
    'title' => __('Front Page : Area Below Slider','modern-magazine'),
    'panel' => 'home_template_settings',
    'description' => __('Using this option you can display the category wise posts on area below slider.','modern-magazine'),
  )
);
$wp_customize->add_setting(
  'latestpost_category',
  array(
    'default' => 'uncategorized',
    'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'latestpost_category',
  array(
    'label' => __('Select Category','modern-magazine'),
    'section' => 'front_page_area_below_slider',
    'type'    => 'select',
    'choices' => modern_magazine_posts_category(),
  )
);
$wp_customize->add_setting(
  'latestpost_category_title',
  array(
    'default' => 'Latest Magazine',
    'sanitize_callback' => 'sanitize_text_field',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'latestpost_category_title',
  array( 
  'label' => __('Section Title','modern-magazine'),     
    'section' => 'front_page_area_below_slider',
    'type'    => 'text',
  )
);
/*Front Page : Content First Magazine Section*/
$wp_customize->add_section(
  'front_page_content_first_magazine_section',
  array(
    'title' => __('Front Page : Content First Section','modern-magazine'),
    'panel' => 'home_template_settings',
    'description' => __('Using this option you can display the category wise posts on content First Section.','modern-magazine'),
  )
);

$wp_customize->add_setting(
  'section_first_news_category',
  array(
    'default' => 'uncategorized',
    'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'section_first_news_category',
  array(
    'label' => __('Select Category','modern-magazine'),
    'section' => 'front_page_content_first_magazine_section',
    'type'    => 'select',
    'choices' => modern_magazine_posts_category(),
  )
);
$wp_customize->add_setting(
  'section_first_news_title',
  array(
    'default' => 'First Magazine',
    'sanitize_callback' => 'sanitize_text_field',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'section_first_news_title',
  array(
    'label' => __('Section Title','modern-magazine'),   
    'section' => 'front_page_content_first_magazine_section',
    'type'    => 'text',
  )
);

/*Front Page : Content Second Magazine Section*/
$wp_customize->add_section(
  'front_page_content_second_magazine_section',
  array(
    'title' => __('Front Page : Content Second Section','modern-magazine'),
    'panel' => 'home_template_settings',
    'description' => __('Using this option you can display the category wise posts on content Second Section.','modern-magazine'),
  )
);
$wp_customize->add_setting(
  'section_second_news_category',
  array(
    'default' => 'uncategorized',
    'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'section_second_news_category',
  array(
    'label' => __('Select Category','modern-magazine'),
    'section' => 'front_page_content_second_magazine_section',
    'type'    => 'select',
    'choices' => modern_magazine_posts_category(),
  )
);
$wp_customize->add_setting(
  'section_second_news_title',
  array(
    'default' => 'Second Magazine',
    'sanitize_callback' => 'sanitize_text_field',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'section_second_news_title',
  array(
    'label' => __('Section Title','modern-magazine'), 
    'section' => 'front_page_content_second_magazine_section',
    'type'    => 'text',
  )
);

/*Front Page : Content Third Magazine Section*/
$wp_customize->add_section(
  'front_page_content_third_magazine_section',
  array(
    'title' => __('Front Page : Content Third Section','modern-magazine'),
    'panel' => 'home_template_settings',
    'description' => __('Using this option you can display the category wise posts on content Third Section.','modern-magazine'),
  )
);
$wp_customize->add_setting(
  'section_third_news_category',
  array(
    'default' => 'uncategorized',
    'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'section_third_news_category',
  array(
    'label' => __('Select Category','modern-magazine'),
    'section' => 'front_page_content_third_magazine_section',
    'type'    => 'select',
    'choices' => modern_magazine_posts_category(),
  )
);
$wp_customize->add_setting(
  'section_third_news_title',
  array(
    'default' => 'Third Magazine',
    'sanitize_callback' => 'sanitize_text_field',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'section_third_news_title',
  array(
    'label' => __('Section Title','modern-magazine'), 
    'section' => 'front_page_content_third_magazine_section',
    'type'    => 'text',
  )
);

/*Front Page : Content Four Magazine Section*/
$wp_customize->add_section(
  'front_page_content_four_magazine_section',
  array(
    'title' => __('Front Page : Content Four Section','modern-magazine'),
    'panel' => 'home_template_settings',
    'description' => __('Using this option you can display the category wise posts on content Four Section.','modern-magazine'),
  )
);
$wp_customize->add_setting(
  'section_four_news_category',
  array(
    'default' => 'uncategorized',
    'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'section_four_news_category',
  array(
    'label' => __('Select Category','modern-magazine'),
    'section' => 'front_page_content_four_magazine_section',
    'type'    => 'select',
    'choices' => modern_magazine_posts_category(),
  )
);
$wp_customize->add_setting(
  'section_four_news_title',
  array(
    'default' => 'Fourth Magazine',
    'sanitize_callback' => 'sanitize_text_field',
    'capability'  => 'edit_theme_options',
  )
);
$wp_customize->add_control(
  'section_four_news_title',
  array(
    'label' => __('Section Title','modern-magazine'), 
    'section' => 'front_page_content_four_magazine_section',
    'type'    => 'text',
  )
);
/*Home page Template settings end */
/**Multiple logo upload code*/

$wp_customize->add_setting('theme_header_fix', array(
        'default' => false,  
        'sanitize_callback' => 'modern_magazine_field_sanitize_checkbox',
));
$wp_customize->add_control('theme_header_fix', array(
    'label'   => esc_html__('Header Fix','modern-magazine'),
    'section' => 'title_tagline',
    'type'    => 'checkbox',
    'priority' => 49
));

$wp_customize->add_setting(
  'theme_logo_height',
  array(
    'default' => '',
    'capability'     => 'edit_theme_options',
    'sanitize_callback' => 'absint',
    )
  );
$wp_customize->add_control(
  'theme_logo_height',
  array(
    'section' => 'title_tagline',
    'label'      => __('Enter Logo Size', 'modern-magazine'),
    'description' => __("Use if you want to increase or decrease logo size (optional) Don't enter 'px' in the string. e.g. 20 (default: 10px)","modern-magazine"),
    'type'       => 'text',
    'priority'    => 50,
    )
  );

$wp_customize->add_setting(
  'theme_sticky_logo_height',
  array(
    'default' => '',
    'capability'     => 'edit_theme_options',
    'sanitize_callback' => 'absint',
    )
  );
$wp_customize->add_control(
  'theme_sticky_logo_height',
  array(
    'section' => 'title_tagline',
    'label'      => __('Enter Sticky Logo Size', 'modern-magazine'),
    'description' => __("Use if you want to increase or decrease Sticky logo size (optional) Don't enter 'px' in the string. e.g. 20 (default: 10px)","modern-magazine"),
    'type'       => 'text',
    'priority'    => 50,
    )
  );

$wp_customize->add_setting(
    'preloader',
    array(
        'default' => '1',
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
        'priority' => 20, 
    )
);
$wp_customize->add_section( 'preloaderSection' , array(
    'title'       => __( 'Preloader', 'modern-magazine' ),
    'priority'    => 32,
    'capability'     => 'edit_theme_options',
    'panel' => 'general'
) );
$wp_customize->add_control(
    'preloader',
    array(
        'section' => 'preloaderSection',                
        'label'   => __('Preloader','modern-magazine'),
        'type'    => 'radio',
        'choices'        => array(
            "1"   => esc_html__( "On ", "modern-magazine" ),
            "2"   => esc_html__( "Off", "modern-magazine" ),
        ),
    )
);

$wp_customize->add_setting( 'customPreloader', array(
    'sanitize_callback' => 'absint',
    'capability'     => 'edit_theme_options',
    'priority' => 40,
));

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'customPreloader', array(
    'label'    => __( 'Upload Custom Preloader', 'modern-magazine' ),
    'section'  => 'preloaderSection',
    'settings' => 'customPreloader',
) ) );

//Remove Background Image Section
$wp_customize->remove_section( 'background_image' );

//Colors section
$wp_customize->add_setting(
    'themeColor',
    array(
        'default' => '#404040',
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'themeColor',
    array(
        'label'      => __('Theme Color ', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 10
    )
  )
);
$wp_customize->add_setting(
  'secondaryColor',
  array(
      'default' => '#e8554e',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'secondaryColor',
    array(
        'label'      => __('Secondary Color', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 11
    )
  )
);
//Menu Background Color
$wp_customize->add_setting(
  'menuBackgroundColor',
  array(
      'default' => '',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'menuBackgroundColor',
    array(
        'label'      => __('Menu Background Color', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 11
    )
  )
);
//Menu Background Color (Scroll)
$wp_customize->add_setting(
  'menuBackgroundColorScroll',
  array(
      'default' => '#fff',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'menuBackgroundColorScroll',
    array(
        'label'      => __('Menu Background Color (after scroll)', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 11
    )
  )
);
//Menu Text Color
$wp_customize->add_setting(
  'menuTextColor',
  array(
      'default' => '#000',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'menuTextColor',
    array(
        'label'      => __('Menu Text Color', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 11
    )
  )
);
//Menu Text Color
$wp_customize->add_setting(
  'menuTextColorScroll',
  array(
      'default' => '#000',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'menuTextColorScroll',
    array(
        'label'      => __('Menu Text Color(after scroll)', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 11
    )
  )
);

//Body Text Color
$wp_customize->add_setting(
  'bodyTextColor',
  array(
      'default' => '#000000',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'bodyTextColor',
    array(
        'label'      => __('Body Text Color', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 11
    )
  )
);
//Footer Background Color
$wp_customize->add_setting(
  'footerBackgroundColor',
  array(
      'default' => '#1d2022',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'footerBackgroundColor',
    array(
        'label'      => __('Footer Background Color', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 14
    )
  )
);
$wp_customize->add_setting(
  'footerTextColor',
  array(
      'default' => '#dddddd ',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'footerTextColor',
    array(
        'label'      => __('Footer Text Color', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 14
    )
  )
);
$wp_customize->add_setting(
  'footerLinkColor',
  array(
      'default' => '#dddddd',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'footerLinkColor',
    array(
        'label'      => __('Footer Link Color', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 14
    )
  )
);
$wp_customize->add_setting(
  'footerLinkHoverColor',
  array(
      'default' => '#e8554e',
      'capability'     => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(
  new WP_Customize_Color_Control(
    $wp_customize,
    'footerLinkHoverColor',
    array(
        'label'      => __('Footer Link Hover Color', 'modern-magazine'),
        'section' => 'colors',
        'priority' => 14
    )
  )
);

/* Color Section Ends */

/*-------------------- BLog Page Option --------------------------*/
$wp_customize->add_section(
    'blogThemeOption',
    array(
        'title' => __( 'Blog Page Options', 'modern-magazine' ),
        'description' => __('Blog page option settings. ','modern-magazine'),
        'priority' => 124,
       
    )
);
$wp_customize->add_setting(
    'blogsidebar',
    array(
        'default' => '2',
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    )
);
$wp_customize->add_control(
    'blogsidebar',
    array(
        'section' => 'blogThemeOption',
        'label'      => __('Select Blog Sidebar Option', 'modern-magazine'),
        'type'       => 'select',
        'choices' => array(
          "1"   => esc_html__( "Left Sidebar", "modern-magazine" ),
          "2"   => esc_html__( "Right Sidebar", "modern-magazine" ),
          "3"   => esc_html__( "Full Sidebar", "modern-magazine" ),          
        ),
    )
);
$wp_customize->add_setting(
    'blogsinglesidebar',
    array(
        'default' => '2',
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    )
);
$wp_customize->add_control(
    'blogsinglesidebar',
    array(
        'section' => 'blogThemeOption',
        'label'      => __('Select Single Post Sidebar Option', 'modern-magazine'),
        'type'       => 'select',
        'choices' => array(
          "1"   => esc_html__( "Left Sidebar", "modern-magazine" ),
          "2"   => esc_html__( "Right Sidebar", "modern-magazine" ),         
          "3"   => esc_html__( "Full Sidebar", "modern-magazine" ),
        ),
    )
);
$wp_customize->add_setting(
    'blogMetaTag',
    array(
        'default' => '1',
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    )
);
$wp_customize->add_control(
    'blogMetaTag',
    array(
        'section' => 'blogThemeOption',
        'label'      => __('Select Blog Post Meta Tag Option', 'modern-magazine'),
        'type'       => 'select',
        'choices' => array(
          "1"   => esc_html__( "Show", "modern-magazine" ),
          "2"   => esc_html__( "Hide", "modern-magazine" ),      
        ),
    )
);
$wp_customize->add_setting(
    'blogSingleMetaTag',
    array(
        'default' => '1',
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    )
);
$wp_customize->add_control(
    'blogSingleMetaTag',
    array(
        'section' => 'blogThemeOption',
        'label'      => __('Select Single Post Meta Tag Option', 'modern-magazine'),
        'type'       => 'select',
        'choices' => array(
          "1"   => esc_html__( "Show", "modern-magazine" ),
          "2"   => esc_html__( "Hide", "modern-magazine" ),      
        ),
    )
);

$wp_customize->add_setting(
    'blogPostExcerpt',
    array(
        'default' => '1',
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    )
);
$wp_customize->add_control(
    'blogPostExcerpt',
    array(
        'section' => 'blogThemeOption',
        'label'      => __('Select Blog Post Excerpt Option', 'modern-magazine'),
        'type'       => 'select',
        'choices' => array(
          "1"   => esc_html__( "Show", "modern-magazine" ),
          "2"   => esc_html__( "Hide", "modern-magazine" ),      
        ),
    )
);
$wp_customize->add_setting(
    'blogPostExcerptTextLimit',
    array(
        'default' => '150',
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'blogPostExcerptTextLimit',
    array(
        'section' => 'blogThemeOption',
        'label'      => __('Blog Post Excerpt String Limit Option', 'modern-magazine'),
        'type'       => 'text',        
    )
);

/*------------------------ Blog  Page option End ----------------------------*/

//Footer Section
$wp_customize->add_panel(
  'footer',
  array(
    'title' => __('Footer','modern-magazine'),
    'description' => __('Footer Options.','modern-magazine'),
    'priority' => 120,
  )
);
$wp_customize->add_section(
  'footerWidgetArea',
  array(
    'title'   => __('Footer Widget Area','modern-magazine'),
    'priority' => 80,
    'capability' => 'edit_theme_options',
    'panel' => 'footer'
  )
);
$wp_customize->add_setting(
  'hideWidgetArea',
  array(
    'default' => 'show',
    'capability'  => 'edit_theme_options',
    'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    'priority'  => 30,
  )
);
$wp_customize->add_control(
    'hideWidgetArea',
    array(
        'section' => 'footerWidgetArea',                
        'label'   => __('Hide Footer Widget Area','modern-magazine'),
        'type'    => 'select',
         'choices' => array(
          "show"   => esc_html__( "Show", "modern-magazine" ),
          "hide"   => esc_html__( "Hide", "modern-magazine" ),      
        ),
    )
);
$wp_customize->add_setting(
  'WidgetAreaStyle',
  array(
    'default' => '3',
    'capability'  => 'edit_theme_options',
    'sanitize_callback' => 'modern_magazine_field_sanitize_input_choice',
    'priority'  => 35,
  )
);
$wp_customize->add_control(
    'WidgetAreaStyle',
    array(
        'section' => 'footerWidgetArea',                
        'label'   => __('Widget Area Style','modern-magazine'),
        'type'    => 'select',
         'choices' => array(
          "1"   => esc_html__( "2 Columns", "modern-magazine" ),
          "2"   => esc_html__( "3 Columns", "modern-magazine" ),      
          "3"   => esc_html__( "4 Columns", "modern-magazine" ),      
        ),
    )
);
$wp_customize->add_section( 'footerCopyright' , array(
    'title'       => __( 'Footer Copyright', 'modern-magazine' ),
    'priority'    => 100,
    'capability'     => 'edit_theme_options',
    'panel'   => 'footer'
  ) );

$wp_customize->add_setting(
    'CopyrightAreaText',
    array(
        'capability'     => 'edit_theme_options',
        'sanitize_callback' => 'wp_kses_post',
        'priority' => 20, 
    )
);
$wp_customize->add_control(
    'CopyrightAreaText',
    array(
        'section' => 'footerCopyright',                
        'label'   => __('Enter Copyright Text','modern-magazine'),
        'type'    => 'textarea',
    )
);
// Text Panel Starts Here 

}
add_action( 'customize_register', 'modern_magazine_customize_register' );

function modern_magazine_custom_css(){
  wp_enqueue_style( 'modern_magazine_style', get_stylesheet_uri() );
  $custom_css= "";

  $custom_css.="
    .responsive-menu, .responsive-menu:hover, .latest-news-headline, .first-section-news-content p .label, .first-section-news-list .news-list-box .news-list-content p .label, .read-more span, .social-icons ul li a, .form-submit input[type='submit'], #cssmenu .button.menu-opened:before, #cssmenu .button.menu-opened:after, .footer-widget .tagcloud a.tag-cloud-link:hover {background: ".esc_attr(get_theme_mod('themeColor','#404040')).";}

    .archive .blog-section-main,.blog .blog-section-main{ box-shadow: 0 1px ".esc_attr(get_theme_mod('themeColor','#404040')).";}
    .page-navigation {    border-top: 1px solid ".esc_attr(get_theme_mod('themeColor','#404040')).";  }

    .first-section-news h2, .second-section-news h2, .third-section-news h2, .fourth-section-news h2, .advertisement h2, .sidebar-search h2, .categories-search h2, .featured-highlights h2, .sidebar-business h2, .popular-posts h2, .blog-main h2, .single-blog-main h2, .comment-main h2, .contact-main h2,.main-sidebar-widget h2{color: ".esc_attr(get_theme_mod('secondaryColor','#e8554e'))."; border-bottom: 2px solid ".esc_attr(get_theme_mod('themeColor','#404040')).";}


    .first-section-news-content h4, .sports-top-content h4 a, .third-section-news-main .date span a, .third-section-news-main h4 a, .fourth-section-news-main .date span a, .fourth-section-news-main h4 a, .categories-link li a, .highlights-content p a, .sidebar-business-content p a, .popular-posts-content p a, .blog-section-main h4 a, .blog-section-main p a, .pagination>li>a, .pagination>li>span, .comment-media .post-name a, h3.letest-title-part, .slider-main-latest-news ol li a, .comment .comment-reply-link, .logged-in-as a, .page-navigation .pagination .nav-links a.page-numbers, .page-navigation .pagination .nav-links span, #cssmenu ul li a, #cssmenu ul ul li a{color: ".esc_attr(get_theme_mod('themeColor','#404040')).";}

    a:hover, .menu li a:hover, .menu li:hover>a, .slider-main .carousel-caption h3 a:hover , .news-box-content h3 a:hover, .news-box-content p a:hover, .latest-news-headline h2, .third-section-news-main h4 a:hover, .fourth-section-news-main h4 a:hover, .categories-link li a:hover , .categories-link li:before, .highlights-content p a:hover, .sidebar-business-content p a:hover, .popular-posts-content p a:hover, .sports-top-content h4 a:hover, .footer li a:hover, .footer li:before, .copy-right a:hover , .blog-section-main p a:hover, .blog-section-main h4 a:hover, .comment-media .post-name a:hover, .slider-main-latest-news ol li, .main-sidebar-widget li a:hover, .main-sidebar-widget li:before, .footer a:hover, .comment .comment-reply-link:hover, .logged-in-as a:hover, .page-navigation .pagination .nav-links .current, .page-navigation .pagination .nav-links a.page-numbers:hover, #cssmenu ul > li > a:hover, #cssmenu .submenu-button:before{color: ".esc_attr(get_theme_mod('secondaryColor','#e8554e')).";}
    
    h3.letest-title-part, #cssmenu .button:after {border-color: ".esc_attr(get_theme_mod('secondaryColor','#e8554e')).";}

    .social-icons ul li a:hover, .read-more span::before,#cssmenu ul > li > a:hover:after, #cssmenu ul > li > a.active:after, .header-area:after, .form-submit .submit:hover, .read-more span:hover, #cssmenu .button:before, .footer-widget .tagcloud a.tag-cloud-link {background: ".esc_attr(get_theme_mod('secondaryColor','#e8554e')).";}

    .bottom-header{background: ".esc_attr(get_theme_mod('menuBackgroundColor')).";}
    .menu li a{color: ".esc_attr(get_theme_mod('menuTextColor','#000')).";}
    body{color: ".esc_attr(get_theme_mod('bodyTextColor','#000')).";}
    .footer{background: ".esc_attr(get_theme_mod('footerBackgroundColor','#1d2022')).";}
    .footer h1, .footer h2, .footer h3, .footer h4, .footer h5, .footer h6, .footer p{color: ".esc_attr(get_theme_mod('footerTextColor','#dddddd')).";}
    .footer a{color: ".esc_attr(get_theme_mod('footerLinkColor','#dddddd')).";}
    .footer a:hover{color: ".esc_attr(get_theme_mod('footerLinkHoverColor','#e8554e')).";}
  ";
  if(get_theme_mod('theme_header_fix',0)){
      $custom_css.= ".sticky.header-area { position :fixed; } 
      @media screen and (max-width:1024px) { .sticky.header-area { position: fixed;}}";
    } 
  $theme_logo_height = (get_theme_mod('theme_logo_height'))?(get_theme_mod('theme_logo_height')):45;
   $theme_sticky_logo_height = (get_theme_mod('theme_sticky_logo_height'))?(get_theme_mod('theme_sticky_logo_height')):45;
    $custom_css.= ".logo img{ max-height: ".esc_attr($theme_logo_height)."px;   }
    .sticky .logo img{ max-height: ".esc_attr($theme_sticky_logo_height)."px;   }    
    ";
    if ( is_super_admin() && is_user_logged_in() ){
      $custom_css.= ".sticky{top: 25px;   }  ";
    }

  wp_add_inline_style( 'modern_magazine_style', $custom_css );

  $custom_js = '';
  if(get_theme_mod('theme_header_fix',0))
  {
   $custom_js .=" jQuery(window).scroll(function () {
      if (jQuery(this).scrollTop() > 10) {
          jQuery('.bottom-header').addClass('header-area sticky');
      } else {
          jQuery('.bottom-header').removeClass('header-area sticky');
      }  

      if (window.matchMedia('(max-width: 1024px)').matches)
      {
          if (jQuery(this).scrollTop() > 10) {
              jQuery('header').addClass('header-area sticky');
              jQuery('.button').addClass('sticky menubar');
          } else {
              jQuery('header').removeClass('header-area sticky');
              jQuery('.button').removeClass('sticky menubar');
          }
      }
  });
  ";
}
  wp_add_inline_script( 'modern-magazine-custom-script', $custom_js );  
}